PRO MAKE_IMAGE, FILE

;- Create a true color image from a MERSI L1 1000M HDF5 file

;- Open the MERSI HDF5 file
file_id = h5f_open(file)

;- Read the solar zenith angle
data_id = h5d_open(file_id, 'SolarZenith')
solzen = h5d_read(data_id)
h5d_close, data_id
solzen = solzen * 0.01

;- Read the red, green, and blue bands
data_id = h5d_open(file_id, 'EV_250_Aggr.1KM_RefSB')
image = h5d_read(data_id)
h5d_close, data_id
band01 = image[*, *, 0]
band02 = image[*, *, 1]
band03 = image[*, *, 2]

;- Close the MERSI HDF5 file
h5f_close, file_id

;- Calibrate the MERSI data to reflectance
band01 = mersi_calibrate(1, band01) / cos(solzen * !dtor)
band02 = mersi_calibrate(2, band02) / cos(solzen * !dtor)
band03 = mersi_calibrate(3, band03) / cos(solzen * !dtor)

;- Create the scaled RGB image
image = scalemodis(band03, band02, band01, /cloud)

;- Increase contrast using histogram clipping
red = image[*, *, 0]
grn = image[*, *, 1]
blu = image[*, *, 2]
range = imclip(red, percent=0.5)
red = bytscl(red, min=range[0], max=range[1])
range = imclip(grn, percent=0.5)
grn = bytscl(grn, min=range[0], max=range[1])
range = imclip(blu, percent=0.5)
blu = bytscl(blu, min=range[0], max=range[1])
image[*, *, 0] = red
image[*, *, 1] = grn
image[*, *, 2] = blu

;- Save the image
write_jpeg, file + '.jpg', image, /order, quality=90, true=3

END
